@@ -1438,7 +1438,7 @@ nasl_exec(lex_ctxt* lexic, tree_cell* st)
 	    }
 
 	  if (len2 == 0 || len1 < len2 || 
-	      (p = (char*)memmem(p1, len1,  p2, len2)) == NULL)
+	      (p = (char*)nasl_memmem(p1, len1,  p2, len2)) == NULL)
 	    {
 	      s3 = emalloc(len1);
 	      memcpy(s3, p1, len1);
@@ -1616,7 +1616,7 @@ nasl_exec(lex_ctxt* lexic, tree_cell* st)
 	}
 
       if(len1 <= len2)		
-      	flag = ((void*)memmem(p2, len2, p1, len1) != NULL);
+      	flag = ((void*)nasl_memmem(p2, len2, p1, len1) != NULL);
       else
       	flag = 0;
 	
