@@ -30,6 +30,7 @@
   
 /*--------------------------------------------------------------------------*/
 #include <includes.h>
+#include "nasl.h"
 
 #include "nasl_tree.h"
 #include "nasl_global_ctxt.h"
@@ -773,3 +774,50 @@ nasl_get_source_port(lex_ctxt* lexic)
   retc->x.i_val = ntohs(ia.sin_port);
   return retc;  
 }
+
+
+
+tree_cell*
+nasl_socket_get_error(lex_ctxt* lexic)
+{
+  int soc = get_int_var_by_num(lexic, 0, -1);
+  tree_cell * retc;
+  int err;
+
+  if ( soc < 0 || ! fd_is_stream(soc) )
+	return NULL;
+
+  err = stream_get_err(soc);
+  retc = alloc_typed_cell(CONST_INT);
+  
+  switch ( err )
+  {
+    case 0 :
+	retc->x.i_val = NASL_ERR_NOERR;
+	break;
+    case ETIMEDOUT:
+	retc->x.i_val = NASL_ERR_ETIMEDOUT;
+	break;
+    case EBADF:
+    case EPIPE:
+#ifdef ECONNRESET
+    case ECONNRESET:
+#endif
+#ifdef ENOTSOCK
+    case ENOTSOCK:
+#endif
+	 retc->x.i_val = NASL_ERR_ECONNRESET;
+         break;
+
+    case ENETUNREACH:
+    case EHOSTUNREACH:
+	 retc->x.i_val = NASL_ERR_EUNREACH;
+         break;
+
+default:
+	fprintf(stderr, "Unknown error %d %s\n", err, strerror(err));
+  }
+
+
+ return retc;
+}
