@@ -976,7 +976,7 @@ nasl_split(lex_ctxt* lexic)
       i = 0; j = 0;
       for(;;)
 	{
-	  if ((p = (char*)memmem(str + i, len - i, sep, sep_len)) == NULL)
+	  if ((p = (char*)nasl_memmem(str + i, len - i, sep, sep_len)) == NULL)
 	    {
 	      v.v.v_str.s_siz = len - i;
 	      v.v.v_str.s_val = (unsigned char*)str + i;
@@ -1150,7 +1150,7 @@ tree_cell* nasl_strstr(lex_ctxt * lexic)
  if(sz_b > sz_a)
   return NULL;
  
- c = (char*)memmem(a, sz_a, b, sz_b);
+ c = (char*)nasl_memmem(a, sz_a, b, sz_b);
  if(c == NULL)
   return FAKE_CELL;
  
@@ -1197,7 +1197,7 @@ nasl_stridx(lex_ctxt * lexic)
   if ((sz_a == start) || (sz_b > sz_a + start))
     return retc;
 
-  c = (char*)memmem(a + start, sz_a - start, b, sz_b);
+  c = (char*)nasl_memmem(a + start, sz_a - start, b, sz_b);
   if(c != NULL)
     retc->x.i_val = c - a;
   return retc;
@@ -1248,7 +1248,7 @@ nasl_str_replace(lex_ctxt * lexic)
   n = 0;
   for (i1 = i2 = 0; i1 < sz_a - sz_b; )
     {
-      c = (char*)memmem(a + i1, sz_a - i1, b, sz_b);
+      c = (char*)nasl_memmem(a + i1, sz_a - i1, b, sz_b);
       if(c == NULL)
 	break;
       l = (c - a) - i1; 
