@@ -302,7 +302,9 @@ get_array_elem(lex_ctxt* ctxt, const char* name, tree_cell* idx)
       switch(idx->type)
 	{
 	case CONST_INT:
-	  av = nasl_get_var_by_num(&u->v.v_arr, idx->x.i_val, 1);
+	  av = nasl_get_var_by_num(&u->v.v_arr, idx->x.i_val, 
+				   /* avoid dangling pointers */
+				   strcmp(name, "_FCT_ANON_ARGS"));
 	  return var2cell(av);
 	  
 	case CONST_STR:
@@ -962,7 +964,9 @@ nasl_read_var_ref(lex_ctxt* lexic, tree_cell* tc)
   v = tc->x.ref_val;
   if (v == NULL)
     {
+#if NASL_DEBUG > 0
       nasl_perror(lexic, "nasl_read_var_ref: NULL variable in REF_VAR\n");
+#endif
       return NULL;
     }
 
@@ -981,7 +985,7 @@ nasl_read_var_ref(lex_ctxt* lexic, tree_cell* tc)
       /* Fix bad string length */
       if (v->v.v_str.s_siz <= 0 && v->v.v_str.s_val[0] != '\0')
 	{
-	  v->v.v_str.s_siz = strlen(v->v.v_str.s_val);
+	  v->v.v_str.s_siz = strlen((char*)v->v.v_str.s_val);
 	  nasl_perror(lexic, "nasl_read_var_ref: Bad string length fixed\n");
 	}
       /* Go on next case */
@@ -1054,7 +1058,7 @@ nasl_incr_variable(lex_ctxt* lexic, tree_cell* tc, int pre, int val)
 #if NASL_DEBUG > 0
       nasl_perror(lexic, "nasl_incr_variable: variable %s is a STRING %s - converting to integer\n", "", get_line_nb(tc));
 #endif
-      old_val = v->v.v_str.s_val == NULL ? 0 : atoi(v->v.v_str.s_val);
+      old_val = v->v.v_str.s_val == NULL ? 0 : atoi((char*)v->v.v_str.s_val);
       break;
     case VAR2_UNDEF:
 #if NASL_DEBUG > 0
@@ -1096,7 +1100,7 @@ var2int(anon_nasl_var* v, int defval)
 
     case VAR2_STRING:
     case VAR2_DATA:
-      return atoi(v->v.v_str.s_val);
+      return atoi((char*)v->v.v_str.s_val);
 
     case VAR2_UNDEF:
 #if NASL_DEBUG > 1
@@ -1559,7 +1563,7 @@ make_array_from_elems(tree_cell* el)
 	      else
 		{
 		  v.v.v_str.s_siz = c2->size;
-		  v.v.v_str.s_val = c2->x.str_val;
+		  v.v.v_str.s_val = (unsigned char*)c2->x.str_val;
 		}
 	      break;
 	    default:
